@@ -13,10 +13,12 @@ import (
 	"github.com/spf13/cobra/doc"
 	"github.com/spf13/pflag"
 	gitlab "gitlab.com/gitlab-org/api/client-go"
-	"gitlab.com/gitlab-org/cli/commands"
+	"gitlab.com/gitlab-org/cli/internal/api"
+	"gitlab.com/gitlab-org/cli/internal/commands"
 	"gitlab.com/gitlab-org/cli/internal/config"
+	"gitlab.com/gitlab-org/cli/internal/glinstance"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
-	"gitlab.com/gitlab-org/cli/pkg/iostreams"
+	"gitlab.com/gitlab-org/cli/internal/iostreams"
 )
 
 func main() {
@@ -41,8 +43,7 @@ func main() {
 		fatal(err)
 	}
 
-	ioStream, _, _, _ := iostreams.Test()
-	glabCli := commands.NewCmdRoot(&factory{io: ioStream}, "", "")
+	glabCli := commands.NewCmdRoot(&factory{io: iostreams.New()})
 	glabCli.DisableAutoGenTag = true
 	if *manpage {
 		if err := genManPage(glabCli, *path); err != nil {
@@ -214,20 +215,20 @@ func GenMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 	}
 
 	if cmd.Runnable() {
-		buf.WriteString(fmt.Sprintf("\n```plaintext\n%s\n```\n", cmd.UseLine()))
+		fmt.Fprintf(buf, "\n```plaintext\n%s\n```\n", cmd.UseLine())
 	}
 
 	if len(cmd.Aliases) > 0 {
 		buf.WriteString("\n## Aliases\n\n")
-		buf.WriteString(fmt.Sprintf("```plaintext\n%s\n```\n", strings.Join(cmd.Aliases, "\n")))
+		fmt.Fprintf(buf, "```plaintext\n%s\n```\n", strings.Join(cmd.Aliases, "\n"))
 	}
 
 	if len(cmd.Example) > 0 {
 		buf.WriteString("\n## Examples\n\n")
-		buf.WriteString(fmt.Sprintf("```console\n%s\n```\n", cmd.Example))
+		fmt.Fprintf(buf, "```console\n%s\n```\n", cmd.Example)
 	}
 
-	if err := printOptions(buf, cmd, name); err != nil {
+	if err := printOptions(buf, cmd); err != nil {
 		return err
 	}
 
@@ -238,7 +239,7 @@ func GenMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 }
 
 // adapted from: github.com/spf13/cobra/blob/main/doc/md_docs.go
-func printOptions(buf *bytes.Buffer, cmd *cobra.Command, name string) error {
+func printOptions(buf *bytes.Buffer, cmd *cobra.Command) error {
 	flags := cmd.NonInheritedFlags()
 	flags.SetOutput(buf)
 	if flags.HasAvailableFlags() {
@@ -261,10 +262,15 @@ type factory struct {
 	io *iostreams.IOStreams
 }
 
-func (f *factory) RepoOverride(repo string) {
+func (f *factory) RepoOverride(repo string) error {
+	return nil
 }
 
-func (f *factory) HttpClient() (*gitlab.Client, error) {
+func (f *factory) ApiClient(repoHost string) (*api.Client, error) {
+	return nil, errors.New("not implemented")
+}
+
+func (f *factory) GitLabClient() (*gitlab.Client, error) {
 	return nil, errors.New("not implemented")
 }
 
@@ -276,8 +282,8 @@ func (f *factory) Remotes() (glrepo.Remotes, error) {
 	return nil, errors.New("not implemented")
 }
 
-func (f *factory) Config() (config.Config, error) {
-	return nil, errors.New("not implemented")
+func (f *factory) Config() config.Config {
+	return nil
 }
 
 func (f *factory) Branch() (string, error) {
@@ -287,3 +293,11 @@ func (f *factory) Branch() (string, error) {
 func (f *factory) IO() *iostreams.IOStreams {
 	return f.io
 }
+
+func (f *factory) DefaultHostname() string {
+	return glinstance.DefaultHostname
+}
+
+func (f *factory) BuildInfo() api.BuildInfo {
+	return api.BuildInfo{}
+}
